# Changelog for Thoth's Template GitHub Project

## Release 0.7.2 (2021-09-14T21:17:26)
### Features
* Update of the dependencies
* change metadata key to reflect new location of cli

## [0.1.0] - 2019-Sep-11 - goern

### Added

all the things that you see...

## Release 0.0.3 (2020-06-25T13:45:47)
* add filter files to docstring
* add ability to filter files
* Adjust link
* Remove self and use Python
* Add example
* Adjust README
* :pushpin: Automatic update of dependency thoth-storages from 0.23.2 to 0.24.0
* Introduce method to retrieve json aggregated
* Add sesheta to contributors
* Add missing import
* Correct docstring
* Add tests and exceptions for SIAggregator class
* Add SI aggregator class
* Update README
* Adjust mypi
* Add enums for store and exceptions
* Make coala and pre-commit happy
* small changes
* Add tests
* Add method
* Add import
* Divide classes
* Remove thoth-python
* Add setup.py
* Remove not necessary files
* Add security ouputs class
* Add requirements
* Add README
* update codeowners
* :arrow_up: updated standard configs, little bit of reformatting
* :sparkles: added a default OWNERS file, dont forget to adjust it!!

## Release 0.1.0 (2020-07-08T19:23:14)
* :pushpin: Automatic update of dependency thoth-storages from 0.24.0 to 0.24.2 (#14)
* Added json to report from Qeb-hwt (#12)
* Update OWNERS

## Release 0.2.0 (2020-07-22T14:58:18)
* Add new adviser methods to Adviser class (#17)
* Update security reports processing (#11)

## Release 0.2.1 (2020-07-24T14:36:16)
* Adjust methods (#20)

## Release 0.2.2 (2020-07-24T16:35:57)
* Add missing packages to requirements.txt (#26)
* :pushpin: Automatic update of dependency thoth-storages from 0.24.4 to 0.24.5 (#25)
* :pushpin: Automatic update of dependency thoth-storages from 0.24.4 to 0.24.5 (#24)

## Release 0.2.3 (2020-08-07T16:42:15)
* Add Inspection class (#31)
* :pushpin: Automatic update of dependency pandas from 1.0.5 to 1.1.0 (#30)
* python script name changed and therefore metadata (#29)

## Release 0.2.4 (2020-08-10T10:48:58)
* Adjust range for daily analysis (#34)

## Release 0.3.0 (2020-08-12T15:42:30)
* Add solver class (#37)
* Feature: add AmunInspectionStatistics class (#38)

## Release 0.3.1 (2020-09-08T13:12:53)
### Features
* Adjust retrieval check of identifier
* Refactor summary report and introduce CPU flags
* Adjust tests
* Modify method for report
* Add new package
* Add filters for runtime environment (#43)
* Default to Ceph (#42)
### Improvements
* Add AmunInspectionsFailedSummary class
* Merge statistics and results
### Non-functional
* Add parameter to performance results (#41)
### Automatic Updates
* :pushpin: Automatic update of dependency pylint from 2.5.3 to 2.6.0 (#50)
* :pushpin: Automatic update of dependency pylint from 2.5.3 to 2.6.0 (#47)
* :pushpin: Automatic update of dependency pytest-mypy from 0.6.2 to 0.7.0 (#48)
* :pushpin: Automatic update of dependency pytest-cov from 2.10.0 to 2.10.1 (#46)
* :pushpin: Automatic update of dependency pandas from 1.1.0 to 1.1.1 (#45)
* :pushpin: Automatic update of dependency thoth-storages from 0.25.0 to 0.25.5 (#44)

## Release 0.3.2 (2020-09-08T14:08:23)
### Features
* Update requirements (#57)

## Release 0.3.3 (2020-09-08T18:23:01)
### Features
* Add missing parameter
* Default to app.py as in version 0.1.2 for si bandit
* Update tests
* Add filter for analyzer-version
### Improvements
* Correct typo
* Use singular for consistency (#60)

## Release 0.3.4 (2020-09-10T13:54:18)
### Non-functional
* Output df for comparison of results and make performance parameters optional (#64)
### Automatic Updates
* :pushpin: Automatic update of dependency pandas from 1.1.1 to 1.1.2 (#67)
* :pushpin: Automatic update of dependency thoth-storages from 0.25.5 to 0.25.6 (#66)

## Release 0.3.5 (2020-10-06T10:53:28)
### Features
* Select adviser-version (#70)
### Automatic Updates
* :pushpin: Automatic update of dependency numpy from 1.19.1 to 1.19.2 (#78)
* :pushpin: Automatic update of dependency numpy from 1.19.1 to 1.19.2 (#77)
* :pushpin: Automatic update of dependency numpy from 1.19.1 to 1.19.2 (#76)
* :pushpin: Automatic update of dependency pandas from 1.1.2 to 1.1.3 (#75)
* :pushpin: Automatic update of dependency pandas from 1.1.2 to 1.1.3 (#74)
* :pushpin: Automatic update of dependency thoth-storages from 0.25.6 to 0.25.15 (#73)
* :pushpin: Automatic update of dependency thoth-storages from 0.25.6 to 0.25.15 (#72)

## Release 0.4.0 (2021-01-14T15:34:12)
### Features
* :arrow_up: Automatic update of dependencies by kebechet. (#91)
* :arrow_up: Automatic update of dependencies by kebechet. (#85)
### Improvements
* Adjust processing (#86)
### Automatic Updates
* :pushpin: Automatic update of dependency pytest from 6.0.1 to 6.1.1 (#83)
* :pushpin: Automatic update of dependency pytest from 6.0.1 to 6.1.1 (#82)
* :pushpin: Automatic update of dependency pytest from 6.0.1 to 6.1.1 (#81)

## Release 0.4.1 (2021-01-19T17:49:26)
### Features
* :arrow_up: Automatic update of dependencies by kebechet. (#98)
* Continue if report is missing (#96)

## Release 0.5.0 (2021-03-16T08:46:12)
### Features
* Allow list of inspection ids retrieval from Ceph
* :arrow_up: Automatic update of dependencies by Kebechet
* Add aicoe.yaml
* update pre-commit
### Improvements
* make pre-commit happy

## Release 0.5.1 (2021-03-24T10:36:59)
### Features
* Make pre-commit happy
* move pytest from aicoe to prow
* Add prow
### Improvements
* Adjust retrieval and processing
* make pre-commit happy
### Other
* remove zuul

## Release 0.6.0 (2021-04-19T09:00:43)
### Features
* Add methods to provide adviser inputs stats (#119)
* :arrow_up: Automatic update of dependencies by Kebechet (#118)
* Include daily statistics on adviser success and failures (#117)
* :arrow_up: Automatic update of dependencies by Kebechet (#116)
* :arrow_up: Automatic update of dependencies by Kebechet
* Do not run checks
### Improvements
* reuse common library methods (#120)
* introduce methods for adviser data analysis for integrations info (#113)

## Release 0.7.0 (2021-04-21T15:35:49)
### Bug Fixes
* Use error msg in result when report is missing (#123)

## Release 0.7.1 (2021-07-02T10:52:02)
### Features
* :arrow_up: Automatic update of dependencies by Kebechet
* :hatched_chick: update the prow resource limits (#126)
* :arrow_up: Automatic update of dependencies by Kebechet
